@@ -6,20 +6,17 @@ from django.http import HttpRequest
 from django.template import Context
 
 from analytical.templatetags.performable import PerformableNode
-from analytical.tests.utils import TagTestCase
+from analytical.tests.utils import TagTestCase, override_settings, SETTING_DELETED
 from analytical.utils import AnalyticalException
 from django.contrib.auth.models import User
 
 
+@override_settings(PERFORMABLE_API_KEY='123ABC')
 class PerformableTagTestCase(TagTestCase):
     """
     Tests for the ``performable`` template tag.
     """
 
-    def setUp(self):
-        super(PerformableTagTestCase, self).setUp()
-        self.settings_manager.set(PERFORMABLE_API_KEY='123ABC')
-
     def test_tag(self):
         r = self.render_tag('performable', 'performable')
         self.assertTrue('/performable/pax/123ABC.js' in r, r)
@@ -28,16 +25,16 @@ class PerformableTagTestCase(TagTestCase):
         r = PerformableNode().render(Context())
         self.assertTrue('/performable/pax/123ABC.js' in r, r)
 
+    @override_settings(PERFORMABLE_API_KEY=SETTING_DELETED)
     def test_no_api_key(self):
-        self.settings_manager.delete('PERFORMABLE_API_KEY')
         self.assertRaises(AnalyticalException, PerformableNode)
 
+    @override_settings(PERFORMABLE_API_KEY='123 ABC')
     def test_wrong_account_number(self):
-        self.settings_manager.set(PERFORMABLE_API_KEY='123 ABC')
         self.assertRaises(AnalyticalException, PerformableNode)
 
+    @override_settings(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
     def test_render_internal_ip(self):
-        self.settings_manager.set(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
         req = HttpRequest()
         req.META['REMOTE_ADDR'] = '1.1.1.1'
         context = Context({'request': req})
@@ -46,8 +43,8 @@ class PerformableTagTestCase(TagTestCase):
                 '<!-- Performable disabled on internal IP address'), r)
         self.assertTrue(r.endswith('-->'), r)
 
+    @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_identify(self):
-        self.settings_manager.set(ANALYTICAL_AUTO_IDENTIFY=True)
         r = PerformableNode().render(Context({'user': User(username='test')}))
         self.assertTrue('_paq.push(["identify", {identity: "test"}]);' in r, r)
 
@@ -58,10 +55,10 @@ class PerformableEmbedTagTestCase(TagTestCase):
     """
 
     def test_tag(self):
-        d = 'example.com'
-        p = 'test'
+        domain = 'example.com'
+        page = 'test'
         r = self.render_tag('performable', 'performable_embed "%s" "%s"'
-                % (d, p))
+                % (domain, page))
         self.assertTrue(
                 "$f.initialize({'host': 'example.com', 'page': 'test'});" in r,
                 r)
